** Jeffrey Clemens 5.11.2017
** Desciption: Clean and Analyze SIPP Data for "Pitfalls in the Development of 
** Falsification Tests: An Illustration from the Recent Minimum Wage Literature"

** Notes: Running this file requires the following data sets:
** 1) sippl08puw`i'.dta for i=1/15 (available through NBER)
** See: http://www.nber.org/data/survey-of-income-and-program-participation-sipp-data.html
** The files sippl08puw`i'.dta are produced by downloading l08puw`i'.dat and 
** running 08w`i'.do and 08w`i'.dct within the required directory structure.
** 2) Macro_Controls.dta
** The file Macro_Controls.dta is available either through the replication packet in 
** which you have obtained this .do file or, as needed, from Jeffrey Clemens. 
** The file contains an FHFA median house price index which, as of 5/11/2017,
** could be downloaded directly from:
** https://www.fhfa.gov/DataTools/Downloads/Documents/HPI/HPI_AT_state.csv
** Note that the median house price index is the only variable from Macro_Controls.dta
** that is required to estimate the "baseline" specification.  Additional control
** variables in Macro_Controls.dta include standard state level data on the employment
** rate, the unemployment rate, and personal income per capita.  The employment
** series are available through the Bureau of Labor Statistics and the personal
** income series is available through the Bureau of Economic Analysis.
** 3) ConstructionBEAForMerge.dta
** This data set contains construction output data from the Bureau of Economic
** Analysis. Like Macro_Controls.dta, it is available either through the replication 
** packet in which you have obtained this .do file or, as needed, from Jeffrey Clemens.
** 4) MinimumWageRatesByStateAndMonth
** This is a modestly revised version of the minimum wage panel from the replication
** materials associated with "Effects of the Minimum Wage on Employment Dynamics" by
** Jonathan Meer and Jeremy West (JHR, 2016).  Note that only states' January 2008
** minimum wage rates are needed to replicate our "baseline" specification.
** These minimum wage rates can, as of 5/11/2017, be found at the following link 
** from the Bureau of Labor Statistics: https://www.dol.gov/whd/state/stateMinWageHis.htm



clear
capture log close 
set matsize 5000


* Set up directory structure
*global workdirectory /Users/cleme/Dropbox/Min Wage
global sippdatadirectory C:\Users\cleme\Dropbox\Min Wage\Raw_SIPP_Data\sipp\2008
global workdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\FalsificationTestReplicationArchive
global logdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\FalsificationTestReplicationArchive
global additionaldatadirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\FalsificationTestReplicationArchive
global resultsdirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\FalsificationTestReplicationArchive\Results
global inferencedirectory C:\Users\cleme\Dropbox\Min Wage\ZippererRebutallPaper\FalsificationTestReplicationArchive\Results\Inference

cd "${workdirectory}"

capture log close
log using "${logdirectory}/FalsificationTestCritique.log", replace


*==================================================
*===== Load SIPP Waves =====
*==================================================
clear

forvalues i=1/15 {
preserve
use "${sippdatadirectory}/sippl08puw`i'.dta", clear
keep ewelac* ersend* erendb* eenrlm eunion1 ersnowrk eptwrk ejbhrs1 rmwkwjb rwksperm rpyper1 ecflag ebuscntr tsbdate1 tebdate1 ejobcntr tfipsst tftotinc rfnkids ulftmain efnp ejbind1 thtrninc eeducate rhcalyr rhcalmn thtotinc thearn ehhnumpp tpearn tptotinc ejbhrs1 rfpov ssuid shhadid eentaid epppnum ehrefper rfid ems tage wpfinwgt renroll esex epayhr1 tpyrate1 tpmsum1 epdjbthn eptwrk ehrsall rmesr rmwkwjb rmhrswk
compress
save "${sippdatadirectory}/temp.dta", replace
restore
append using "${sippdatadirectory}/temp.dta"
}

erase "${sippdatadirectory}/temp.dta"


*==================================================
*===== Rename Variables =====
*==================================================
destring epppnum, replace
rename rhcalyr year
rename rhcalmn month
rename tfipsst statefip
order statefip year month

*==================================================
*===== Add Macroeconomics Controls =====
*==================================================
merge m:1 statefip year month using "${additionaldatadirectory}/Macro_Controls.dta", nogenerate
replace index = index/1000
replace unemployment_rate = unemployment_rate/100
replace personal_income = personal_income/1000

gen quarter = 1
replace quarter = 2 if month >= 4 & month <= 6
replace quarter = 3 if month >= 7 & month <= 9
replace quarter = 4 if month >= 10 & month <= 12
*** Merge in 05-06 industry share variables
merge m:1 statefip using "${additionaldatadirectory}/QCEW0506indshares.dta"
keep if _merge == 3
drop _merge

merge m:1 statefip using "${additionaldatadirectory}/IndexDeclineMatchVariables.dta"
keep if _merge == 3 
drop _merge



*==================================================
*===== Initial Cleaning =====
*==================================================
egen personid = group(ssuid epppnum)
drop if missing(personid)

drop if tage>=65
drop if tage<16

gen time = 100*year+month
drop if time<=200807
drop if time>201207

gen tpearnB = tpearn

foreach inc in tpearn {
replace `inc' = `inc'/CPI
replace `inc' = 0 if `inc'<0
replace `inc' = 7500 if `inc' > 7500 & `inc' != .
}

egen personidcount = count(personid), by(personid)
keep if personidcount >= 36



*==================================================
*===== Identify Bound States and =====
*==================================================
preserve 
use "${additionaldatadirectory}/MinimumWageRatesByStateAndMonth.dta", clear
keep if year==2008 & month==1
keep statefip mw
replace mw = round(mw,.01)
rename mw mw2008
save "${additionaldatadirectory}/Jan2008MWs.dta", replace
restore
merge m:1 statefip using "${additionaldatadirectory}/Jan2008MWs.dta", nogenerate

gen Treatment = mw2008<6.55

gen Post = time>=200908
gen Post1 = time>=200908 & time<=201007
gen Post2 = time>=201008
gen Transition = time>=200905 & time<=200907
gen Period = 0
replace Period = 1 if Transition==1
replace Period = 2 if Post1==1
replace Period = 3 if Post2==1

gen Treatment_Post = Treatment*Post
gen Treatment_Post_1 = Treatment*Post1
gen Treatment_Post_2 = Treatment*Post2
gen Treatment_Trans = Treatment*Transition

*==================================================
*===== Outcome Variables =====
*==================================================
gen employed = rmesr >= 1 & rmesr <= 5
gen noearn = employed==0 | tpmsum1==0
gen intern = employed==1 & tpmsum1==0


*==============================================================
*== Create wage and average baseline wage variables ====
*==============================================================
gen hours = ehrsall
replace hours = 0 if ehrsall<0
gen tothours = hours*rmwkwjb

gen hourwageZ = tpearnB/tothours if ejobcntr >=0
gen hrwageZ = tpyrate1 if ejobcntr >=0
replace hrwageZ = hourwageZ if tpyrate1==0 & !missing(hourwage) 
replace hrwageZ = round(hrwageZ,.01)

gen hourwage = tpearn/tothours if ejobcntr >=0
gen hrwage = tpyrate1 if ejobcntr >=0
replace hrwage = hourwage if tpyrate1==0 & !missing(hourwage) 
replace hrwage = round(hrwage,.01)
gen affectedwage = hrwage>=5.15 & hrwage<7.25

gen wagevar = hrwage if  Post==0
egen avewage = mean(wagevar), by(personid)

gen wagevarZ = hrwageZ if  Post==0
egen avewageZ = mean(wagevarZ), by(personid)


*==================================================
*== Create Target Samples
*==================================================
*** First gropuing uses the baseline approach
gen group = 0 if avewage== .
replace group = 1 if avewage<7.50
replace group = 2 if avewage>=7.50 & avewage <8.50
replace group = 3 if avewage>=8.50 & avewage <10.00
replace group = 4 if avewage>=10.00 & avewage != . 

gen groupZ = 0 if avewageZ== .
replace groupZ = 1 if avewageZ<7.50
replace groupZ = 2 if avewageZ>=7.50 & avewageZ <8.50
replace groupZ = 3 if avewageZ>=8.50 & avewageZ <10.00
replace groupZ = 4 if avewageZ>=10.00 & avewageZ != . 



*==================================================================
*===== Additional Variables Needed For Analysis =====
*==================================================================
gen region = 0
replace region = 1 if statefip == 9 | statefip == 23 | statefip == 25 | statefip == 33 | statefip == 44 | statefip == 50
replace region = 1 if statefip == 34 | statefip == 36 | statefip == 42
replace region = 2 if statefip == 17 | statefip == 18 | statefip == 26 | statefip == 39 | statefip == 55 
replace region = 2 if statefip == 19 | statefip == 20 | statefip == 27 | statefip == 29 | statefip == 31 | statefip == 38 | statefip == 46
replace region = 3 if statefip == 10 | statefip == 11 | statefip == 12 | statefip == 13 | statefip == 24 | statefip == 37 | statefip == 45 | statefip == 51 | statefip == 54
replace region = 3 if statefip == 1 | statefip == 21 | statefip == 28 | statefip == 47
replace region = 3 if statefip == 5 | statefip == 22 | statefip == 40 | statefip == 48
replace region = 4 if statefip == 4 | statefip == 8 | statefip == 16 | statefip == 30 | statefip == 32 | statefip == 35 | statefip == 49 | statefip == 56
replace region = 4 if statefip == 2 | statefip == 6 | statefip == 15 | statefip == 41 | statefip == 53

gen division = 0
replace division = 1 if statefip == 9 | statefip == 23 | statefip == 25 | statefip == 33 | statefip == 44 | statefip == 50
replace division = 2 if statefip == 34 | statefip == 36 | statefip == 42
replace division = 3 if statefip == 17 | statefip == 18 | statefip == 26 | statefip == 39 | statefip == 55 
replace division = 4 if statefip == 19 | statefip == 20 | statefip == 27 | statefip == 29 | statefip == 31 | statefip == 38 | statefip == 46
replace division = 5 if statefip == 10 | statefip == 11 | statefip == 12 | statefip == 13 | statefip == 24 | statefip == 37 | statefip == 45 | statefip == 51 | statefip == 54
replace division = 6 if statefip == 1 | statefip == 21 | statefip == 28 | statefip == 47
replace division = 7 if statefip == 5 | statefip == 22 | statefip == 40 | statefip == 48
replace division = 8 if statefip == 4 | statefip == 8 | statefip == 16 | statefip == 30 | statefip == 32 | statefip == 35 | statefip == 49 | statefip == 56
replace division = 9 if statefip == 2 | statefip == 6 | statefip == 15 | statefip == 41 | statefip == 53

gen placebotreatmentA = 0
replace placebotreatmentA = 1 if region == 3 & Treatment == 0

gen placebotreatmentB = 0
replace placebotreatmentB = 1 if (division == 8 & Treatment == 0) | (division == 5 & Treatment == 0)


*** Examination of Zipperer's Placebo Test
gen placebotreatmentA_Post_1 = placebotreatmentA == 1 & Post1 == 1
gen placebotreatmentA_Post_2 = placebotreatmentA == 1 & Post2 == 1
gen placebotreatmentA_Trans = placebotreatmentA == 1 & Transition == 1

gen placebotreatmentB_Post_1 = placebotreatmentB == 1 & Post1 == 1
gen placebotreatmentB_Post_2 = placebotreatmentB == 1 & Post2 == 1
gen placebotreatmentB_Trans = placebotreatmentB == 1 & Transition == 1

gen empejobcntr = ejobcntr >= 0



*** Falsification test analysis
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweights", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsMoreMacro", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsNoFLAZ", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsMatch", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsIND", replace

areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeights", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsMoreMacro", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsNoFLAZ", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsMatch", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsIND", replace

areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsMoreMacroZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if groupZ==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsNoFLAZZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if groupZ==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsMatchZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPNoweightsINDZipR", replace

areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsMoreMacroZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsNoFLAZZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsMatchZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboRegionSIPPWeightsINDZipR", replace

 
drop placebotreatmentA_Post_1  placebotreatmentA_Post_2 placebotreatmentA_Trans 
gen placebotreatmentA_Post_1  = placebotreatmentB_Post_1
gen placebotreatmentA_Post_2  = placebotreatmentB_Post_2
gen placebotreatmentA_Trans  = placebotreatmentB_Trans 

areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweights", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsMoreMacro", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsNoFLAZ", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsMatch", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsIND", replace

areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeights", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsMoreMacro", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsNoFLAZ", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if group==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsMatch", replace
areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsIND", replace

areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsMoreMacroZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if groupZ==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsNoFLAZZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if groupZ==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsMatchZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPNoweightsINDZipR", replace

areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time i.Period##c.unemployment_rate i.Period##c.personal_income i.Period##c.employment_rate i.Period##c.index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsMoreMacroZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012 & statefip != 12 & statefip != 4, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsNoFLAZZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012 & ismatched02 == 1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsMatchZipR", replace
areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/PlaceboDivisionSIPPWeightsINDZipR", replace



*** Baseline and Zipperer industry
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPP", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1IndSIPP", replace

*** Baseline and Zipperer industry (weighted)
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time [aw = wpfinwgt] if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1BaseSIPPWghts", replace
areg employed Treatment_Post_1 Treatment_Post_2 Treatment_Trans index i.statefip i.time##(c.industry1011share0506 c.industry1012share0506 c.industry1013share0506 c.industry1021share0506 c.industry1022share0506 c.industry1023share0506 c.industry1024share0506 c.industry1025share0506 c.industry1026share0506 c.industry1027share0506) [aw = wpfinwgt] if group==1, absorb(personid) cluster(statefip)
estimates save "${resultsdirectory}/EmployedGroup1IndSIPPWghts", replace




	
capture drop placebotreatmentA placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans 

**** Full sample placebo policy change distribution
keep if group == 1 | groupZ == 1
sort statefip
egen firstobs = seq(), by(statefip)
replace firstobs = . if firstobs != 1
set seed  9999


**** Generate placebo distribution for baseline specification 
forval i = 1/500 {

	gen x =runiform(0,1)
	replace x = . if firstobs == .
	sort x 
	gen rank = _n 
	replace rank = . if firstobs != 1
	list x rank statefip if firstobs == 1

	egen staterank = max(rank), by(statefip)
	
	gen placebotreatmentA = 0
	replace placebotreatmentA = 1 if staterank <= 27 & staterank >= 1
	gen placebotreatmentA_Post_1 = placebotreatmentA == 1 & Post1 == 1
	gen placebotreatmentA_Post_2 = placebotreatmentA == 1 & Post2 == 1
	gen placebotreatmentA_Trans = placebotreatmentA == 1 & Transition == 1

	areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1, absorb(personid) cluster(statefip)
	parmest,format(estimate min95 max95 %8.3f p %8.1e) saving("${inferencedirectory}\FullPlacebo`i'C.dta", replace)
	
	drop x rank staterank placebotreatmentA placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans 
}


**** Code for placebo policy change distribution
keep if group == 1 & Treatment == 0
sort statefip
capture drop firstobs
egen firstobs = seq(), by(statefip)
replace firstobs = . if firstobs != 1
set seed  9999

forval i = 1/500 {

	gen x =runiform(0,1)
	replace x = . if firstobs == .
	sort x 
	gen rank = _n 
	replace rank = . if firstobs != 1
	list x rank statefip if firstobs == 1

	egen staterank = max(rank), by(statefip)
	
	gen placebotreatmentA = 0
	replace placebotreatmentA = 1 if staterank <= 3 & staterank >= 1
	gen placebotreatmentA_Post_1 = placebotreatmentA == 1 & Post1 == 1
	gen placebotreatmentA_Post_2 = placebotreatmentA == 1 & Post2 == 1
	gen placebotreatmentA_Trans = placebotreatmentA == 1 & Transition == 1

	areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
	parmest,format(estimate min95 max95 %8.3f p %8.1e) saving("${inferencedirectory}\Placebo`i'C.dta", replace)
	areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
	parmest,format(estimate min95 max95 %8.3f p %8.1e) saving("${inferencedirectory}\Placebo`i'CZipR.dta", replace)
	
	drop x rank staterank placebotreatmentA placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans 
}


forval i = 1/500 {

	gen x =runiform(0,1)
	replace x = . if firstobs == .
	sort x 
	gen rank = _n 
	replace rank = . if firstobs != 1
	list x rank statefip if firstobs == 1

	egen staterank = max(rank), by(statefip)
	
	gen placebotreatmentA = 0
	replace placebotreatmentA = 1 if staterank <= 5 & staterank >= 1
	gen placebotreatmentA_Post_1 = placebotreatmentA == 1 & Post1 == 1
	gen placebotreatmentA_Post_2 = placebotreatmentA == 1 & Post2 == 1
	gen placebotreatmentA_Trans = placebotreatmentA == 1 & Transition == 1

	areg employed placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index if group==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
	parmest,format(estimate min95 max95 %8.3f p %8.1e) saving("${inferencedirectory}\Placebo`i'CDiv5.dta", replace)
	areg empejobcntr placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans i.statefip i.time index [aw = wpfinwgt] if groupZ==1 & Treatment == 0 & year < 2012, absorb(personid) cluster(statefip)
	parmest,format(estimate min95 max95 %8.3f p %8.1e) saving("${inferencedirectory}\Placebo`i'CDiv5ZipR.dta", replace)
	
	drop x rank staterank placebotreatmentA placebotreatmentA_Post_1 placebotreatmentA_Post_2 placebotreatmentA_Trans 
}




use "${inferencedirectory}\Placebo1C.dta", clear
forval i = 2/500 {
	append using "${inferencedirectory}\Placebo`i'C.dta"
}

label var estimate "Estimate on Randomly Assigned Placebo Treatment"
sum estimate if parm == "placebotreatmentA_Post_2", detail
hist estimate if parm == "placebotreatmentA_Post_2", title("Permutation Test on Zipperer Region Exercise") color(white)  blcolor(red) width(.01) frac xlabel(-.2(.1).2) graphregion(color(white)) name(hist1, replace)
keep if parm == "placebotreatmentA_Post_2"
sort estimate

use "${inferencedirectory}\Placebo1CDiv5.dta", clear
forval i = 2/500 {
	capture append using "${inferencedirectory}\Placebo`i'CDiv5.dta"	
}

label var estimate "Estimate on Randomly Assigned Placebo Treatment"
sum estimate if parm == "placebotreatmentA_Post_2", detail
hist estimate if parm == "placebotreatmentA_Post_2", title("Permutation Test on Zipperer Division Exercise") color(white)  blcolor(red) width(.01) frac xlabel(-.2(.1).2) graphregion(color(white)) name(hist2, replace)
keep if parm == "placebotreatmentA_Post_2"
sort estimate



use "${inferencedirectory}\Placebo1CZipR.dta", clear
forval i = 2/500 {
	append using "${inferencedirectory}\Placebo`i'CZipR.dta"	
}

label var estimate "Estimate on Randomly Assigned Placebo Treatment"
sum estimate if parm == "placebotreatmentA_Post_2", detail
hist estimate if parm == "placebotreatmentA_Post_2", title("Permutation Test on Zipperer Region Exercise") color(white)  blcolor(red) width(.01) frac xlabel(-.2(.1).2) graphregion(color(white)) name(hist4, replace)
keep if parm == "placebotreatmentA_Post_2"
sort estimate



use "${inferencedirectory}\Placebo1CDiv5ZipR.dta", clear
forval i = 2/500 {
	capture append using "${inferencedirectory}\Placebo`i'CDiv5ZipR.dta"	
}

label var estimate "Estimate on Randomly Assigned Placebo Treatment"
sum estimate if parm == "placebotreatmentA_Post_2", detail
hist estimate if parm == "placebotreatmentA_Post_2", title("Permutation Test on Zipperer Division Exercise") color(white)  blcolor(red) width(.01) frac xlabel(-.2(.1).2) graphregion(color(white)) name(hist5, replace)
keep if parm == "placebotreatmentA_Post_2"
sort estimate




use "${inferencedirectory}\FullPlacebo1C.dta", clear
forval i = 2/500 {
	append using "${inferencedirectory}\FullPlacebo`i'C.dta"	
}

label var estimate "Estimate on Randomly Assigned Placebo Treatment"
sum estimate if parm == "placebotreatmentA_Post_2", detail
hist estimate if parm == "placebotreatmentA_Post_2", title("Permutation Test on Clemens and Wither Baseline") color(white)  blcolor(red) width(.01) xline(-0.066, lcolor(black) lpattern(dash)) frac xlabel(-.2(.1).2) graphregion(color(white)) name(hist3, replace)
keep if parm == "placebotreatmentA_Post_2"
sort estimate


capture log close
